Learn R Programming

soptdmaeA (version 1.0.0)

graphsoptd.mae: Creates the graphical layout of resultant sequential optimal design

Description

Creates the graphical layout of resultant sequential A-, MV-, D- or E-optimal or near-optimal block or row-column design on a separate pop-up GUI tcltk window.

Usage

graphsoptd.mae(trt.N, blk.N, theta, soptdesF, Optcrit, strt, sary, dtype)

Arguments

trt.N

integer, specifying number of treatments v of resultant sequential optimal design, soptdesF.

blk.N

integer, specifying number of arrays b of resultant sequential optimal design, soptdesF.

theta

numeric, representing a function of the ratio of random array variance and random error variance. It takes any value between 0 and 1, inclusive.

soptdesF

matrix, a 2 x b obtained sequential optimal or near-optimal block or row-column design.

Optcrit

character specifying the optimality criteria to be used. Thus, Optcrit takes the letter "A", "MV", "D" and "E" for A-, MV-, D- and E-optimal or near-optimal block or row-column designs, respectively.

strt

a non-negative integer, specifying number of added treatments/conditions to the initial design.

sary

a non-negative integer, specifying number of added arrays to the initial design.

dtype

character, specifying the design type. For block designs, dtype = "blkd" and for row-column deigns, dtype = "rcd".

Value

Returns the graphical layout of the resultant sequential optimal or near-optimal block or row-column design 'soptdesF' on a separate pop-up window with the new edges (arrays) and vertices (treatments) added to the initial design coloured in red and brown, respectively, for separation purpose. Furthermore, the function graphsoptd.mae saves the graphical layout of the initial des0 and resultant sequential optimal or near-optimal design in .pdf format in a working subdirectory.

Details

Detail discussions concerning the constructions of graph can be found in igraph R package.

See Also

igraph