Alternative to directly using the function soptdmaeA on the R console, the function mmenusoptd.mae creates the main menu tcltk window with the list of four optimality criteria (A, MV, D and E) for search of sequential optimal or near-optimal block or row-column designs for two-colour cDNA microarray experiments.
mmenusoptd.mae()The main menu window created using the function mmenusoptd.mae contains the list of four optimality criteria (the A-,
MV -, D- and E) for sequential block or row-column designs that allows user to choose an optimality criterion of interest. The function
will then call for a function fixparsoptd.mae for further option regarding the setup of parametric combinations, initial optimal or near-optimal design, and output, see fixparsoptd.mae documentation.